# Installation
`pip install su-vtda`

# Visual Training Dynamics Analysis
`Problems of mislabeling and bias on large datasets can be investigated through novel training dynamics based methods. This study contains implementation of an open-source Python library which brings state-of-the-art tools together to visualize and analyze training dynamics as well as experimental combinations of several metrics on data map visualizations along with notebooks. By grouping and organizing recent packages and modules within literature, Visual Training Dynamics Analysis (VTDA) library provides easier access to visualization tools and allows users to categorize instances based on the metrics they intend to analyze training dynamics with. Code is available at https://github.com/ekcmert/VTDA`

# Notes
`Old notebooks might not work but can be used to understand the way we implemented this library. REPAIR and REVISE packages are not fully implemented yet. However, their source codes are included in VTDA for the future works.`